@@ -959,7 +959,7 @@ class GTKTrayMenuBase(object):
         c.set_draw_as_radio(True)
         c.set_active(False)
         def scaling_activated(item):
-            if scaling_submenu.updating:
+            if scaling_submenu.updating or not item.get_active():
                 return
             ensure_item_selected(scaling_submenu, item)
             self.client.scaleset(item.scalingvalue, item.scalingvalue)
@@ -995,11 +995,11 @@ class GTKTrayMenuBase(object):
         return self.client.quality
     def set_min_quality(self, q):
         self.client.min_quality = q
-        self.client.quality = 0
+        self.client.quality = -1
         self.client.send_min_quality()
         self.client.send_quality()
     def set_quality(self, q):
-        self.client.min_quality = 0
+        self.client.min_quality = -1
         self.client.quality = q
         self.client.send_min_quality()
         self.client.send_quality()
@@ -1044,11 +1044,11 @@ class GTKTrayMenuBase(object):
         return self.client.speed
     def set_min_speed(self, s):
         self.client.min_speed = s
-        self.client.speed = 0
+        self.client.speed = -1
         self.client.send_min_speed()
         self.client.send_speed()
     def set_speed(self, s):
-        self.client.min_speed = 0
+        self.client.min_speed = -1
         self.client.speed = s
         self.client.send_min_speed()
         self.client.send_speed()
@@ -1558,7 +1558,7 @@ class GTKTrayMenuBase(object):
             dialog.destroy()
             if response == SHUTDOWN:
                 self.client.send_shutdown_server()
-        self.shutdown = self.menuitem("Shutdown Server", "shutdown.png", cb=ask_shutdown_confirm)
+        self.shutdown = self.menuitem("Shutdown Session", "shutdown.png", cb=ask_shutdown_confirm)
         def enable_shutdown(*args):
             log("enable_shutdown%s can_shutdown_server=%s", args, self.client.server_client_shutdown)
             set_sensitive(self.shutdown, self.client.server_client_shutdown)
