@@ -1047,8 +1047,8 @@ class WindowClient(StubClientMixin):
         aw = max(1, self.sx(w))
         ah = max(1, self.sy(h))
         resize_counter = -1
-        if len(packet)>4:
-            resize_counter = packet[4]
+        if len(packet)>6:
+            resize_counter = packet[6]
         window = self._id_to_window.get(wid)
         geomlog("_process_window_move_resize%s moving / resizing window %s (id=%s) to %s",
                 packet[1:], window, wid, (ax, ay, aw, ah))
@@ -1330,10 +1330,12 @@ class WindowClient(StubClientMixin):
             self.reinit_windows()
         self.reinit_window_icons()
 
-    def control_refresh(self, wid, suspend_resume, refresh, quality=100, options={}, client_properties={}):
+    def control_refresh(self, wid, suspend_resume, refresh, quality=100, options=None, client_properties=None):
         if not self.window_buffer_refresh:
             return
         packet = ["buffer-refresh", wid, 0, quality]
+        options = options or {}
+        client_properties = client_properties or {}
         options["refresh-now"] = bool(refresh)
         if suspend_resume is True:
             options["batch"] = {
