@@ -122,7 +122,7 @@ def load_icon_from_theme(icon_name, theme=None):
     return load_icon_from_file(filename)
 
 def load_glob_icon(submenu_data, main_dirname="categories"):
-    if not LOAD_GLOB:
+    if not LOAD_GLOB or not EXPORT_ICONS:
         return None
     #doesn't work with IconTheme.getIconPath,
     #so do it the hard way:
@@ -271,6 +271,8 @@ def do_load_xdg_menu_data():
                     log("do_load_xdg_menu_data()", exc_info=True)
                     error = e
                     menu = None
+            if menu:
+                break
     if menu is None:
         if error:
             log.error("Error parsing xdg menu data:")
