@@ -63,6 +63,9 @@ def has_sound_support():
 
 
 def get_xorg_bin():
+    xorg = os.environ.get("XPRA_XORG_BIN")
+    if xorg:
+        return xorg
     # Detect Xorg Binary
     if os.uname()[4].startswith("arm") and is_Debian() and os.path.exists("/usr/bin/Xorg"):
         #Raspbian breaks if we use a different binary..
@@ -201,7 +204,7 @@ def OpenGL_safety_check():
         try:
             f = None
             f = open("\\\\.\\VBoxMiniRdrDN", "r")
-            return True, "VirtualBox is present (VBoxMiniRdrDN)"
+            return "VirtualBox is present (VBoxMiniRdrDN)"
         finally:
             if f:
                 f.close()
@@ -574,7 +577,7 @@ OPTION_TYPES = {
                     "attach"            : bool,
                     "use-display"       : bool,
                     "fake-xinerama"     : str,
-                    "resize_display"    : bool,
+                    "resize-display"    : bool,
                     "tray"              : bool,
                     "pulseaudio"        : bool,
                     "dbus-proxy"        : bool,
@@ -720,7 +723,9 @@ CLIENT_OPTIONS = ["title", "username", "password", "session-name",
                   "env"]
 
 CLIENT_ONLY_OPTIONS = ["username", "swap-keys", "dock-icon",
-                       "tray", "delay-tray", "tray-icon"]
+                       "tray", "delay-tray", "tray-icon",
+                       "attach",
+                       ]
 
 #options that clients can pass to the proxy
 #and which will be forwarded to the new proxy instance process:
@@ -738,7 +743,7 @@ PROXY_START_OVERRIDABLE_OPTIONS = [
     "input-method",
     "microphone", "speaker", "sound-source", "pulseaudio",
     "idle-timeout", "server-idle-timeout",
-    "use-display", "fake-xinerama", "resize_display", "dpi", "pixel-depth",
+    "use-display", "fake-xinerama", "resize-display", "dpi", "pixel-depth",
     "readonly", "keyboard-sync", "cursors", "bell", "notifications", "xsettings",
     "system-tray", "sharing", "lock", "windows", "webcam", "html",
     "terminate-children", "exit-with-children", "exit-with-client",
@@ -876,9 +881,8 @@ def get_defaults():
     if sys.version_info<(2, 7, 9):
         ssl_protocol = "SSLv23"
 
-    if POSIX and not OSX:
-        from xpra.x11.fakeXinerama import find_libfakeXinerama
-        fake_xinerama = find_libfakeXinerama()
+    if POSIX and not OSX and not (is_Debian() or is_Ubuntu()):
+        fake_xinerama = "auto"
     else:
         fake_xinerama = "no"
 
@@ -1162,7 +1166,10 @@ def parse_with_unit(numtype, v, subunit="bps", min_value=250000):
         raise InitException("invalid value for %s '%s': %s" % (numtype, v, e))
 
 
-def validate_config(d={}, discard=NO_FILE_OPTIONS, extras_types={}, extras_validation={}):
+def validate_config(d=None, discard=NO_FILE_OPTIONS, extras_types=None, extras_validation=None):
+    return do_validate_config(d or {}, discard, extras_types or {}, extras_validation or {})
+
+def do_validate_config(d, discard, extras_types, extras_validation):
     """
         Validates all the options given in a dict with fields as keys and
         strings or arrays of strings as values.
@@ -1220,16 +1227,20 @@ def validate_config(d={}, discard=NO_FILE_OPTIONS, extras_types={}, extras_valid
     return nd
 
 
-def make_defaults_struct(extras_defaults={}, extras_types={}, extras_validation={}, username="", uid=getuid(), gid=getgid()):
+def make_defaults_struct(extras_defaults=None, extras_types=None, extras_validation=None, username="", uid=getuid(), gid=getgid()):
+    return do_make_defaults_struct(extras_defaults or {}, extras_types or {}, extras_validation or {}, username, uid, gid)
+
+def do_make_defaults_struct(extras_defaults, extras_types, extras_validation, username, uid, gid):
     #populate config with default values:
     if not username and uid:
         username = get_username_for_uid(uid)
     defaults = read_xpra_defaults(username, uid, gid)
     return dict_to_validated_config(defaults, extras_defaults, extras_types, extras_validation)
 
-def dict_to_validated_config(d={}, extras_defaults={}, extras_types={}, extras_validation={}):
+def dict_to_validated_config(d, extras_defaults=None, extras_types=None, extras_validation=None):
     options = get_defaults().copy()
-    options.update(extras_defaults)
+    if extras_defaults:
+        options.update(extras_defaults)
     #parse config:
     validated = validate_config(d, extras_types=extras_types, extras_validation=extras_validation)
     options.update(validated)
