@@ -9,7 +9,7 @@ import os.path
 
 from xpra.util import parse_scaling_value, from0to100
 from xpra.server.control_command import ArgsControlCommand, ControlError
-from xpra.os_util import load_binary_file
+from xpra.os_util import load_binary_file, bytestostr, strtobytes
 from xpra.util import csv
 from xpra.scripts.config import parse_bool, FALSE_OPTIONS, TRUE_OPTIONS
 from xpra.server.mixins.stub_server_mixin import StubServerMixin
@@ -93,7 +93,7 @@ class ServerBaseControlCommands(StubServerMixin):
             ArgsControlCommand("scaling",               "set a specific scaling value",     min_args=1, validation=[parse_scaling_value]),
             ArgsControlCommand("auto-refresh",          "set a specific auto-refresh value", min_args=1, validation=[float]),
             ArgsControlCommand("refresh",               "refresh some or all windows",      min_args=0),
-            ArgsControlCommand("encoding",              "picture encoding",                 min_args=1, max_args=1),
+            ArgsControlCommand("encoding",              "picture encoding",                 min_args=2),
             ArgsControlCommand("video-region-enabled",  "enable video region",              min_args=2, max_args=2, validation=[int, parse_boolean_value]),
             ArgsControlCommand("video-region-detection","enable video detection",           min_args=2, max_args=2, validation=[int, parse_boolean_value]),
             ArgsControlCommand("video-region-exclusion-zones","set window regions to exclude from video regions: 'WID,(x,y,w,h),(x,y,w,h),..', ie: '1 (0,10,100,20),(200,300,20,20)'",  min_args=2, max_args=2, validation=[int, parse_4intlist]),
@@ -241,6 +241,13 @@ class ServerBaseControlCommands(StubServerMixin):
         return "url sent to %i clients" % clients
 
     def control_command_send_file(self, filename, openit="open", client_uuids="*", maxbitrate=0):
+        #we always get the values as strings from the command interface,
+        #but those may actually be utf8 encoded binary strings,
+        #so we may have to do an ugly roundtrip:
+        try:
+            filename = strtobytes(filename).decode("utf8")
+        except:
+            filename = bytestostr(filename)
         openit = str(openit).lower() in ("open", "true", "1")
         return self.do_control_file_command("send file", client_uuids, filename, "file_transfer", (False, openit))
 
