@@ -31,6 +31,7 @@ X11Keyboard = X11KeyboardBindings()
 
 MAP_MISSING_MODIFIERS = envbool("XPRA_MAP_MISSING_MODIFIERS", True)
 SIMULATE_MODIFIERS = envbool("XPRA_SIMULATE_MODIFIERS", True)
+SHIFT_LOCK = envbool("XPRA_SHIFT_LOCK", False)
 
 ALL_X11_MODIFIERS = {
                     "shift"     : 0,
@@ -445,7 +446,7 @@ class KeyboardConfig(KeyboardConfigBase):
         self.keycode_mappings = get_keycode_mappings()
 
 
-    def do_get_keycode(self, client_keycode, keyname, pressed, modifiers, group):
+    def do_get_keycode(self, client_keycode, keyname, pressed, modifiers, keystr, group):
         if not self.enabled:
             log("ignoring keycode since keyboard is turned off")
             return -1, group
@@ -462,7 +463,8 @@ class KeyboardConfig(KeyboardConfigBase):
                 return self.do_get_keycode_new(client_keycode, keyname, pressed, modifiers, group)
             #non-native: try harder to find matching keysym
             #first, try to honour shift state:
-            shift = ("shift" in modifiers) ^ ("lock" in modifiers)
+            lock = ("lock" in modifiers) and (SHIFT_LOCK or (bool(keystr) and keystr.isalpha()))
+            shift = ("shift" in modifiers) ^ lock
             mode = 0
             for mod in modifiers:
                 names = self.keynames_for_mod.get(mod, [])
@@ -501,7 +503,8 @@ class KeyboardConfig(KeyboardConfigBase):
         def klog(msg, *args):
             kmlog("do_get_keycode%s"+msg, (client_keycode, keyname, pressed, modifiers, group), *args)
         #first, try to honour shift state:
-        shift = ("shift" in modifiers) ^ ("lock" in modifiers)
+        lock = ("lock" in modifiers) and (SHIFT_LOCK or (bool(keystr) and keystr.isalpha()))
+        shift = ("shift" in modifiers) ^ lock
         mode = 0
         numlock = 0
         numlock_modifier = None
